@@ -423,7 +423,7 @@ static std::map<NamedGroup, std::unique_ptr<KeyExchange>> getKeyExchangers(
     const std::vector<NamedGroup>& groups) {
   std::map<NamedGroup, std::unique_ptr<KeyExchange>> keyExchangers;
   for (auto group : groups) {
-    auto kex = factory.makeKeyExchange(group, Factory::KeyExchangeMode::Client);
+    auto kex = factory.makeKeyExchange(group, KeyExchangeRole::Client);
     kex->generateKeyPair();
     keyExchangers.emplace(group, std::move(kex));
   }
@@ -440,6 +440,7 @@ static ClientHello getClientHello(
     const std::vector<SignatureScheme>& supportedSigSchemes,
     const std::vector<PskKeyExchangeMode>& supportedPskModes,
     const folly::Optional<std::string>& hostname,
+    const bool sniExtFirst,
     const std::vector<std::string>& supportedAlpns,
     const std::vector<CertificateCompressionAlgorithm>& compressionAlgos,
     const Optional<EarlyDataParams>& earlyDataParams,
@@ -453,6 +454,14 @@ static ClientHello getClientHello(
   chlo.cipher_suites = supportedCiphers;
   chlo.legacy_compression_methods.push_back(0x00);
 
+  if (sniExtFirst) {
+    if (hostname) {
+      auto hostnameBuf = folly::IOBuf::copyBuffer(*hostname);
+      auto sni = ServerNameList(ServerName(std::move(hostnameBuf)));
+      chlo.extensions.push_back(encodeExtension(sni));
+    }
+  }
+
   SupportedVersions versions;
   versions.versions = supportedVersions;
   chlo.extensions.push_back(encodeExtension(std::move(versions)));
@@ -474,10 +483,12 @@ static ClientHello getClientHello(
   sigAlgs.supported_signature_algorithms = supportedSigSchemes;
   chlo.extensions.push_back(encodeExtension(std::move(sigAlgs)));
 
-  if (hostname) {
-    auto hostnameBuf = folly::IOBuf::copyBuffer(*hostname);
-    auto sni = ServerNameList(ServerName(std::move(hostnameBuf)));
-    chlo.extensions.push_back(encodeExtension(sni));
+  if (!sniExtFirst) {
+    if (hostname) {
+      auto hostnameBuf = folly::IOBuf::copyBuffer(*hostname);
+      auto sni = ServerNameList(ServerName(std::move(hostnameBuf)));
+      chlo.extensions.push_back(encodeExtension(sni));
+    }
   }
 
   if (!supportedAlpns.empty()) {
@@ -684,8 +695,8 @@ static folly::Optional<ECHParams> setupECH(
   auto echConfigContent = decode<ech::ECHConfigContentDraft>(cursor);
   auto fakeSni = echConfigContent.public_name->clone();
   auto kemId = echConfigContent.key_config.kem_id;
-  auto kex = factory.makeKeyExchange(
-      getKexGroup(kemId), Factory::KeyExchangeMode::Client);
+  auto kex =
+      factory.makeKeyExchange(getKexGroup(kemId), KeyExchangeRole::Client);
   auto setupResult =
       constructHpkeSetupResult(std::move(kex), supportedECHConfig);
 
@@ -849,6 +860,7 @@ EventHandler<ClientTypes, StateEnum::Uninitialized, Event::Connect>::handle(
       context->getSupportedSigSchemes(),
       context->getSupportedPskModes(),
       sni,
+      context->getSniExtFirst(),
       context->getSupportedAlpns(),
       context->getSupportedCertDecompressionAlgorithms(),
       earlyDataParams,
@@ -1541,6 +1553,7 @@ Actions EventHandler<
       state.context()->getSupportedSigSchemes(),
       state.context()->getSupportedPskModes(),
       std::move(sni),
+      state.context()->getSniExtFirst(),
       state.context()->getSupportedAlpns(),
       state.context()->getSupportedCertDecompressionAlgorithms(),
       folly::none,
