@@ -8,6 +8,7 @@
 
 #include <gtest/gtest.h>
 
+#include <fizz/backend/openssl/Hasher.h>
 #include <fizz/backend/openssl/OpenSSL.h>
 #include <fizz/crypto/aead/test/TestUtil.h>
 #include <fizz/crypto/hpke/Context.h>
@@ -54,8 +55,8 @@ TEST_P(HpkeContextTest, TestContext) {
       toIOBuf(kExportSecret),
       std::make_unique<fizz::hpke::Hkdf>(
           kPrefix->clone(),
-          std::make_unique<HkdfImpl>(
-              HkdfImpl(Sha256::HashLen, &openssl::Hasher<Sha256>::hmac))),
+          std::make_unique<::fizz::Hkdf>(
+              Sha256::HashLen, &openssl::makeHasher<Sha256>)),
       suiteId->clone(),
       fizz::hpke::HpkeContext::Role::Sender);
   auto gotCiphertext = encryptContext.seal(
@@ -71,8 +72,8 @@ TEST_P(HpkeContextTest, TestContext) {
       toIOBuf(kExportSecret),
       std::make_unique<fizz::hpke::Hkdf>(
           kPrefix->clone(),
-          std::make_unique<HkdfImpl>(
-              HkdfImpl(Sha256::HashLen, &openssl::Hasher<Sha256>::hmac))),
+          std::make_unique<::fizz::Hkdf>(
+              Sha256::HashLen, &openssl::makeHasher<Sha256>)),
       std::move(suiteId),
       fizz::hpke::HpkeContext::Role::Receiver);
   auto gotPlaintext = decryptContext.open(
@@ -95,8 +96,8 @@ TEST_P(HpkeContextTest, TestContextRoles) {
       toIOBuf(kExportSecret),
       std::make_unique<fizz::hpke::Hkdf>(
           kPrefix->clone(),
-          std::make_unique<HkdfImpl>(
-              HkdfImpl(Sha256::HashLen, &openssl::Hasher<Sha256>::hmac))),
+          std::make_unique<::fizz::Hkdf>(
+              Sha256::HashLen, &openssl::makeHasher<Sha256>)),
       suiteId->clone(),
       fizz::hpke::HpkeContext::Role::Sender);
 
@@ -108,8 +109,8 @@ TEST_P(HpkeContextTest, TestContextRoles) {
       toIOBuf(kExportSecret),
       std::make_unique<fizz::hpke::Hkdf>(
           kPrefix->clone(),
-          std::make_unique<HkdfImpl>(
-              HkdfImpl(Sha256::HashLen, &openssl::Hasher<Sha256>::hmac))),
+          std::make_unique<::fizz::Hkdf>(
+              Sha256::HashLen, &openssl::makeHasher<Sha256>)),
       std::move(suiteId),
       fizz::hpke::HpkeContext::Role::Receiver);
 
@@ -142,8 +143,8 @@ TEST_P(HpkeContextTest, TestExportSecret) {
         toIOBuf(testParam.exporterSecret),
         std::make_unique<fizz::hpke::Hkdf>(
             kPrefix->clone(),
-            std::make_unique<HkdfImpl>(
-                HkdfImpl(Sha256::HashLen, &openssl::Hasher<Sha256>::hmac))),
+            std::make_unique<::fizz::Hkdf>(
+                Sha256::HashLen, &openssl::makeHasher<Sha256>)),
         std::move(suiteId),
         role);
     auto secret = context.exportSecret(std::move(exporterContext), 32);
@@ -171,8 +172,8 @@ TEST_P(HpkeContextTest, TestExportSecretThrow) {
         toIOBuf(testParam.exporterSecret),
         std::make_unique<fizz::hpke::Hkdf>(
             kPrefix->clone(),
-            std::make_unique<HkdfImpl>(
-                HkdfImpl(Sha256::HashLen, &openssl::Hasher<Sha256>::hmac))),
+            std::make_unique<::fizz::Hkdf>(
+                Sha256::HashLen, &openssl::makeHasher<Sha256>)),
         std::move(suiteId),
         role);
 
