@@ -267,7 +267,7 @@ TEST_F(KTLSReadTest, BasicReadWrite) {
         clientRead_->read(clientReadQueue_, fizz::Aead::AeadOptions());
     ASSERT_TRUE(message.has_value());
     EXPECT_EQ(message->type, fizz::ContentType::application_data);
-    auto data = message->fragment->moveToFbString().toStdString();
+    auto data = message->fragment->to<std::string>();
     EXPECT_EQ("goodbye world", data);
   }
 }
@@ -405,8 +405,8 @@ TEST_F(KTLSReadTest, HandshakeDispatch) {
       .WillOnce(Invoke([&](auto&&, fizz::NewSessionTicket ticket) {
         EXPECT_EQ(ticket.ticket_lifetime, 100);
         EXPECT_EQ(ticket.ticket_age_add, 20);
-        EXPECT_EQ("abc", ticket.ticket_nonce->moveToFbString().toStdString());
-        EXPECT_EQ("123", ticket.ticket->moveToFbString().toStdString());
+        EXPECT_EQ("abc", ticket.ticket_nonce->to<std::string>());
+        EXPECT_EQ("123", ticket.ticket->to<std::string>());
         serverConn_->setReadCB(nullptr);
       }));
   serverConn_->setReadCB(&mockReadCB_);
@@ -459,8 +459,8 @@ TEST_F(KTLSReadTest, HandshakeRecordSmallBuffer) {
       .WillOnce(Invoke([&](auto&&, fizz::NewSessionTicket ticket) {
         EXPECT_EQ(ticket.ticket_lifetime, 100);
         EXPECT_EQ(ticket.ticket_age_add, 20);
-        EXPECT_EQ("abc", ticket.ticket_nonce->moveToFbString().toStdString());
-        EXPECT_EQ("123", ticket.ticket->moveToFbString().toStdString());
+        EXPECT_EQ("abc", ticket.ticket_nonce->to<std::string>());
+        EXPECT_EQ("123", ticket.ticket->to<std::string>());
         serverConn_->setReadCB(nullptr);
       }));
   serverConn_->setReadCB(&mockReadCB_);
@@ -524,8 +524,8 @@ TEST_F(KTLSReadTest, HandshakeMessageAcrossRecords) {
       .WillOnce(Invoke([&](auto&&, fizz::NewSessionTicket ticket) {
         EXPECT_EQ(ticket.ticket_lifetime, 100);
         EXPECT_EQ(ticket.ticket_age_add, 20);
-        EXPECT_EQ("abc", ticket.ticket_nonce->moveToFbString().toStdString());
-        EXPECT_EQ("123", ticket.ticket->moveToFbString().toStdString());
+        EXPECT_EQ("abc", ticket.ticket_nonce->to<std::string>());
+        EXPECT_EQ("123", ticket.ticket->to<std::string>());
         serverConn_->setReadCB(nullptr);
       }));
   evb_.loop();
