@@ -57,6 +57,10 @@ class BatchSignatureFactory : public Factory {
     return original_->makeKeyDeriver(cipher);
   }
 
+  HasherFactory makeHasher(HashFunction digest) const override {
+    return original_->makeHasher(digest);
+  }
+
   std::unique_ptr<HandshakeContext> makeHandshakeContext(
       CipherSuite cipher) const override {
     return original_->makeHandshakeContext(cipher);
