@@ -89,9 +89,7 @@ template <typename Hash>
 inline std::unique_ptr<KeyDerivation> makeKeyDerivationPtr() {
   return std::unique_ptr<KeyDerivationImpl>(new KeyDerivationImpl(
       Hash::HashLen,
-      &openssl::Hasher<Hash>::hash,
-      &openssl::Hasher<Hash>::hmac,
-      HkdfImpl(Hash::HashLen, &openssl::Hasher<Hash>::hmac),
+      Hkdf(Hash::HashLen, ::fizz::openssl::makeHasher<Hash>),
       Hash::BlankHash));
 }
 } // namespace detail
@@ -113,20 +111,25 @@ std::unique_ptr<KeyDerivation> MultiBackendFactory::makeKeyDeriver(
   }
 }
 
+HasherFactory MultiBackendFactory::makeHasher(HashFunction digest) const {
+  switch (digest) {
+    case HashFunction::Sha256:
+      return openssl::makeHasher<fizz::Sha256>;
+    case HashFunction::Sha384:
+      return openssl::makeHasher<fizz::Sha384>;
+    case HashFunction::Sha512:
+      return openssl::makeHasher<fizz::Sha512>;
+    default:
+      throw std::runtime_error("makeHasher: not implemented");
+  }
+}
 std::unique_ptr<HandshakeContext> MultiBackendFactory::makeHandshakeContext(
     CipherSuite cipher) const {
-  switch (cipher) {
-    case CipherSuite::TLS_CHACHA20_POLY1305_SHA256:
-    case CipherSuite::TLS_AES_128_GCM_SHA256:
-    case CipherSuite::TLS_AES_128_OCB_SHA256_EXPERIMENTAL:
-    case CipherSuite::TLS_AEGIS_128L_SHA256:
-      return std::make_unique<HandshakeContextImpl<fizz::Sha256>>();
-    case CipherSuite::TLS_AES_256_GCM_SHA384:
-    case CipherSuite::TLS_AEGIS_256_SHA512:
-      return std::make_unique<HandshakeContextImpl<fizz::Sha384>>();
-    default:
-      throw std::runtime_error("hs: not implemented");
-  }
+  auto hashFunction = getHashFunction(cipher);
+  auto blankHash = getBlankHash(hashFunction);
+  auto hasherFactory = makeHasher(hashFunction);
+
+  return std::make_unique<HandshakeContextImpl>(hasherFactory, blankHash);
 }
 
 std::unique_ptr<PeerCert> MultiBackendFactory::makePeerCert(
