@@ -8,7 +8,7 @@
 
 #include <folly/portability/GTest.h>
 
-#include <fizz/backend/openssl/OpenSSLFactory.h>
+#include <fizz/protocol/DefaultFactory.h>
 #include <fizz/protocol/Exporter.h>
 
 using namespace folly;
@@ -22,7 +22,7 @@ StringPiece basic_expected_ekm = {
     "55549d2d280d8507823a80c2ee69530e5dcc6a04e86f1bae1ef23a86337341a8"};
 
 TEST(ExporterTest, TestExporterBasic) {
-  openssl::OpenSSLFactory factory;
+  fizz::DefaultFactory factory;
   auto ekm = Exporter::getExportedKeyingMaterial(
       factory,
       CipherSuite::TLS_AES_128_GCM_SHA256,
